package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````%"````````!``````````$BA````
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````%R/````````7(\`````````
M``$```````$````&````@)L```````"`FP$``````(";`0``````^`0`````
M``!0%0```````````0```````@````8```"0FP```````)";`0``````D)L!
M``````#@`0```````.`!````````"`````````!0Y71D!````#B)````````
M.(D````````XB0```````/0`````````]``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"`FP```````(";`0``````@)L!``````"`!```````
M`(`$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!.````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$X```!/````4P```%@```!9````8````&$```!B`````````&0`
M``!E`````````&8```!G````:@```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`#@:
M`````````````````````````P`2``"@`0`````````````````!````$@``
M``````````````````````#/`0``$@`````````````````````````)````
M$0````````````````````````#U`0``$0````````````````````````!Q
M`0``$@`````````````````````````0````$@``````````````````````
M``"N`0``$@`````````````````````````8````$@``````````````````
M```````?````$@`````````````````````````"`@``$@``````````````
M``````````"Z`0``$@`````````````````````````H````(```````````
M```````````````?`P``(0````````````````````````!`````$@``````
M``````````````````!&````$@````````````````````````!-````$@``
M``````````````````````#L`@``$@````````````````````````#=`@``
M$@````````````````````````"'`@``$@````````````````````````!4
M````$@`````````````````````````H`@``$@``````````````````````
M``!;````$@````````````````````````"\`@``$@``````````````````
M``````!B````$@````````````````````````!J````$@``````````````
M``````````"E`@``$@````````````````````````!R````$@``````````
M``````````````!X````$@````````````````````````"!````(```````
M``````````````````#6`@``$@````````````````````````"=````$@``
M``````````````````````"B````$@`````````````````````````3`@``
M$0````````````````````````##`@``$@````````````````````````!5
M`@``$@````````````````````````"I````$@``````````````````````
M``!'`@``$@````````````````````````!E`P``$@``````````````````
M```````>`P``$0````````````````````````!Y`@``$@``````````````
M```````````+`P``$@`````````````````````````@`P``$0``````````
M``````````````"P````$@`````````````````````````#`P``$@``````
M``````````````````"Y````$0````````````````````````!_`0``$@``
M``````````````````````#+````(@````````````````````````#:````
M(`````````````````````````#P````$@````````````````````````#.
M`@``$@````````````````````````!E`@``$@``````````````````````
M``#U````$@````````````````````````#[````(```````````````````
M``````"P`@``$@`````````````````````````5`0``$@``````````````
M``````````"?`0``$@`````````````````````````:`0``$@``````````
M``````````````"5`@``$@````````````````````````".`0``$@``````
M```````````````````@`0``$@`````````````````````````Q`0``$@``
M```````````````````````C`@``$@````````````````````````!S````
M$@`````````````````````````T`@``$@````````````````````````!N
M`@``$@````````````````````````#\`@``$@``````````````````````
M```W`0``$@````````````````````````#T`@``$@``````````````````
M``````!+`0``$@`````````````````````````>`@``$@``````````````
M``````````#=`0``$@````````````````````````!2`0``$@``````````
M``````````````!9`0``$@`````````````````````````=`P``(0``````
M``````````````````!J`0``$@````````````````````````!E!```$``3
M`-"P`0`````````````````8`P``$@`)`%`>````````Q`$```````#O`0``
M$@`*`-Q+````````!`````````"G`P``$@`)`"@N````````!`8```````!U
M!```$@`)`'@W````````9`````````"$`P``$@`)`%PH````````!```````
M```9!```$@`'`#@:````````!`````````#*`P``$@`)`"PT````````3`,`
M```````?!```$``3`'B@`0````````````````!-!```$@`)`&`H````````
MU`$````````"!```$``3`'B@`0````````````````"5`P``$@`)`'0M````
M````M`````````"T`P``$@`)`*`F````````.`````````"\`P``$@`)`/PL
M````````6`````````#@`P``$@`)`-A(````````<`$```````#U`P``$@`)
M`#0J````````(``````````.!```$``3`-"P`0````````````````!P!```
M$``3`-"P`0````````````````!*`P``$@`)`#`@````````*``````````M
M!```$@`)`%0J````````!`$```````#K`P``$0`2`'"@`0``````"```````
M``!&!```$``2`'B@`0`````````````````'!```$@`)`!0@````````````
M```````6!```$@`)`'Q(````````7`````````!3`P``$@`)`%0M````````
M(`````````!N`P``$@`)`"PG````````,`$```````!:!```$@`)`$A*````
M````E`$```````!D!```$``3`-"P`0`````````````````Y!```$@`)`%@K
M````````I`$`````````;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'-T<F-M<`!M96US970`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!L<W1A=`!C
M;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S
M='(`<W1R8VAR`')E861L:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA7V9I
M;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`&-L;W-E`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T
M:6]N`&UK9&ER`'!T:')E861?9V5T<W!E8VEF:6,`;65M8W!Y`'-T<FQE;@!?
M7W-T86-K7V-H:U]F86EL`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G
M971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L
M7W-V7S)P=E]F;&%G<P!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`
M8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C
M`'!E<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A
M9&1I<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN
M`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM86%R8V@V-"YS;RXQ
M`%]S=&%R=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P
M871H`'!A<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E
M;F%M90!?7V)S<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T
M7U\`<&%R7V1I<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R
M;V<`<VAA7V9I;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S
M<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``(";`0```````P0````````P
M(0```````(B;`0```````P0```````#0(````````("?`0```````P0`````
M``!0'@```````)B?`0```````P0```````#<2P```````+"?`0```````P0`
M```````X&@````````"@`0```````P0`````````H`$``````!"@`0``````
M`P0```````#L2P```````!B@`0```````P0````````73````````"B@`0``
M`````P0```````#Q2P```````#"@`0```````P0```````#Q3````````#B@
M`0```````P0```````#\2P```````$"@`0```````P0````````#30``````
M`$B@`0```````P0````````$3````````%B@`0```````P0````````(3```
M`````&"@`0```````P0````````-3````````'"@`0```````P0```````"E
M3@```````(B?`0```````00```4``````````````)"?`0```````00```8`
M`````````````*"?`0```````00```X``````````````*B?`0```````00`
M`!\``````````````+B?`0```````00``",``````````````,"?`0``````
M`00``"P``````````````,B?`0```````00``"\``````````````-"?`0``
M`````00``#$``````````````-B?`0```````00``#(``````````````."?
M`0```````00``#<``````````````.B?`0```````00``#P`````````````
M`/"?`0```````00``#T``````````````/B?`0```````00``$(`````````
M`````(B=`0```````@0```,``````````````)"=`0```````@0```0`````
M`````````)B=`0```````@0```<``````````````*"=`0```````@0```@`
M`````````````*B=`0```````@0```D``````````````+"=`0```````@0`
M``H``````````````+B=`0```````@0```L``````````````,"=`0``````
M`@0```P``````````````,B=`0```````@0```T``````````````-"=`0``
M`````@0```X``````````````-B=`0```````@0``!```````````````."=
M`0```````@0``!$``````````````.B=`0```````@0``!(`````````````
M`/"=`0```````@0``!,``````````````/B=`0```````@0``!0`````````
M``````">`0```````@0``!4```````````````B>`0```````@0``!8`````
M`````````!">`0```````@0``!<``````````````!B>`0```````@0``!@`
M`````````````"">`0```````@0``!D``````````````"B>`0```````@0`
M`!H``````````````#">`0```````@0``!L``````````````#B>`0``````
M`@0``!P``````````````$">`0```````@0``!T``````````````$B>`0``
M`````@0``!X``````````````%">`0```````@0``"```````````````%B>
M`0```````@0``"$``````````````&">`0```````@0``"(`````````````
M`&B>`0```````@0``"0``````````````'">`0```````@0``"4`````````
M`````'B>`0```````@0``"8``````````````(">`0```````@0``"<`````
M`````````(B>`0```````@0``"@``````````````)">`0```````@0``"H`
M`````````````)B>`0```````@0``"L``````````````*">`0```````@0`
M`"T``````````````*B>`0```````@0``"X``````````````+">`0``````
M`@0``#```````````````+B>`0```````@0``#$``````````````,">`0``
M`````@0``#(``````````````,B>`0```````@0``#,``````````````-">
M`0```````@0``#0``````````````-B>`0```````@0``#4`````````````
M`.">`0```````@0``#8``````````````.B>`0```````@0``#@`````````
M`````/">`0```````@0``#D``````````````/B>`0```````@0``#H`````
M``````````"?`0```````@0``#L```````````````B?`0```````@0``#X`
M`````````````!"?`0```````@0``#\``````````````!B?`0```````@0`
M`$```````````````""?`0```````@0``$$``````````````"B?`0``````
M`@0``$,``````````````#"?`0```````@0``$0``````````````#B?`0``
M`````@0``$4``````````````$"?`0```````@0``$8``````````````$B?
M`0```````@0``$<``````````````%"?`0```````@0``$@`````````````
M`%B?`0```````@0``$D``````````````&"?`0```````@0``$H`````````
M`````&B?`0```````@0``$L``````````````'"?`0```````@0``$T`````
M`````````/U[OZG]`P"1_7O!J,`#7]8``````````/![OZG0``"0$<)&^1`"
M-I$@`A_6'R`#U1\@`]4?(`/5T```D!'&1OD0(C:1(`(?UM```)`1RD;Y$$(V
MD2`"'];0``"0$<Y&^1!B-I$@`A_6T```D!'21OD0@C:1(`(?UM```)`1UD;Y
M$*(VD2`"'];0``"0$=I&^1#"-I$@`A_6T```D!'>1OD0XC:1(`(?UM```)`1
MXD;Y$`(WD2`"'];0``"0$>9&^1`B-Y$@`A_6T```D!'J1OD00C>1(`(?UM``
M`)`1[D;Y$&(WD2`"'];0``"0$?)&^1""-Y$@`A_6T```D!'V1OD0HC>1(`(?
MUM```)`1^D;Y$,(WD2`"'];0``"0$?Y&^1#B-Y$@`A_6T```D!$"1_D0`CB1
M(`(?UM```)`1!D?Y$"(XD2`"'];0``"0$0I'^1!".)$@`A_6T```D!$.1_D0
M8CB1(`(?UM```)`1$D?Y$((XD2`"'];0``"0$19'^1"B.)$@`A_6T```D!$:
M1_D0PCB1(`(?UM```)`1'D?Y$.(XD2`"'];0``"0$2)'^1`".9$@`A_6T```
MD!$F1_D0(CF1(`(?UM```)`1*D?Y$$(YD2`"'];0``"0$2Y'^1!B.9$@`A_6
MT```D!$R1_D0@CF1(`(?UM```)`1-D?Y$*(YD2`"'];0``"0$3I'^1#".9$@
M`A_6T```D!$^1_D0XCF1(`(?UM```)`10D?Y$`(ZD2`"'];0``"0$49'^1`B
M.I$@`A_6T```D!%*1_D00CJ1(`(?UM```)`13D?Y$&(ZD2`"'];0``"0$5)'
M^1"".I$@`A_6T```D!%61_D0HCJ1(`(?UM```)`16D?Y$,(ZD2`"'];0``"0
M$5Y'^1#B.I$@`A_6T```D!%B1_D0`CN1(`(?UM```)`19D?Y$"([D2`"'];0
M``"0$6I'^1!".Y$@`A_6T```D!%N1_D08CN1(`(?UM```)`1<D?Y$(([D2`"
M'];0``"0$79'^1"B.Y$@`A_6T```D!%Z1_D0PCN1(`(?UM```)`1?D?Y$.([
MD2`"'];0``"0$8)'^1`"/)$@`A_6T```D!&&1_D0(CR1(`(?UM```)`1BD?Y
M$$(\D2`"'];0``"0$8Y'^1!B/)$@`A_6T```D!&21_D0@CR1(`(?UM```)`1
MED?Y$*(\D2`"'];0``"0$9I'^1#"/)$@`A_6T```D!&>1_D0XCR1(`(?UM``
M`)`1HD?Y$`(]D2`"'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?
MUM```)`1KD?Y$&(]D2`"'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1
M(`(?UM```)`1ND?Y$,(]D2`"'];]>[NI_0,`D?-3`:G3``"PU```D/43`/GB
MAP.IXN,`D>$#`9'@3P"YX#,!D9'__Y?"``"0P```D$+\1_D`^$?YX0,"JB__
M_Y?```"0`,A'^0``0#F``0`U8O__EV+"`I%`#`#Y8```M2``@%*-__^7I/__
MEX#>1_D``$"YP?__EQ\D*3F4WD?Y@`)`N;W__Y<!:%(Y(0`?,@%H$CF``D"Y
MN/__EP%H4CDA```R`6@2.>!/0+D`%``1`'Q]DXG__Y?A(T#YXP,`JF+"`I$@
M`$#Y8```^0```/``?#J18`0`^<```+!#!`#Y`#A`^6`(`/D```#P`(@ZD6`,
M`/F``(!20`0`N0``@-+B3T"Y``0`D5\``&L,!0!4=<("D4(,`!$$`(#2`0``
ML"%@&Y&@#D#Y?]@B^!/__Y?T`P`J@```-:`.0/E?__^7]`,`*G7"`I&@#D#Y
M-___EP```/``K#*1G```E&`!`+6@"D#YH```M0```/``@#&1E@``E*`*`/E@
MP@*1``A`^4```+3G!0"4<\("D6`.0/F&__^7J?[_E^`#%"KS4T&I]1-`^?U[
MQ:C``U_6!`P`$25X8/AEV"3XT___%QT`@-(>`(#2X`,`D:$``/`A0"Z1'^Q\
MD@$``!3B`P"JI```\*,``/"@``#PA,Q'^04`@-)CV$?Y`,!'^4&$0/@/__\7
M'R`#U1\@`]7```"0`.`!D<$``)`AX`&1/P``Z\```%2A``#P(=1'^6$``+3P
M`P&J``(?UL`#7];```"0`.`!D<$``)`AX`&1(0``RR+\?]-!#(&+(?Q!D\$`
M`+2B``#P0O!'^6(``+3P`P*J``(?UL`#7]8?(`/5_7N^J?T#`)'S"P#YTP``
MD&#B03D``@`UH```\`#H1_F```"TP```D```0/GU_O^7V/__EZ```/``T$?Y
M@```M"```-``P"B1>O[_ER``@%)@X@$Y\PM`^?U[PJC``U_6H```\`#L1_E`
M`0"T_7N_J<$``)`@``#0_0,`D2$``I$`P"B1X_[_E_U[P:C-__\7S/__%_U[
MO*G]`P"1\U,!J?5;`JGW8P.I``4`M/8#`*J@``#P`.!'^1<`0/EW!`"T^`,!
MJN(#%JI``$`Y'_0`<0080'HA`P!40@`62_4#%ZI3?$"3M`)`^=0!`+3B`Q.J
MX0,6JN`#%*I^_O^7(`(`-8!J<S@?]`!QP0$`5+4"%\MS!@"1E`(3B[7^0Y,5
M`P"YX`,4JO-30:GU6T*I]V-#J?U[Q*C``U_60@0`D>/__Q>U(@"1Z/__%Q0`
M@-+U__\7_7N]J?T#`)'S"P#YLP``\'/F1_EA`D#YX1<`^0$`@-+ADP"1R/__
ME^(70/EA`D#Y00`!RD$``+3V_O^7\PM`^?U[PZC``U_6_7N\J:$``/#]`P"1
M\U,!J?0#`*KS`P&J(.1'^?5;`JFU``#P`@!`^>(?`/D"`(#2]M,`D;7B1_GA
M`Q:JX`,4JJ___Y?@``"U8>9'^>(?0/D@`$#Y0```RD`!`+3;_O^7H`)`^>(W
M@+D"#`*+0`1`^4```/D@_O^T0B``D?S__Q?S4T&I]5M"J?U[Q*C``U_6_7NR
MJ?T#`)'U6P*IM@``\,'F1_GS4P&I]V,#J?EK!*DB`$#YXF\`^0(`@-*``@"T
M`0!`.?0#`*HA`@`TS_W_E_<#`*K``0"T&```T!D``-`87S"1.5LPD1H``-#@
M`Q>J^OW_E_,#`*I@`0"UX`,7JB+^_Y?@`Q2J?/[_E];F1_GA;T#YP`)`^2``
M`,I`!0"TJO[_EW-.`)'A`QBJX`,3JN;]_Y?`_?\TX0,9JN`#$ZKB_?^70/W_
M-.`#%*J;_O^7]0,`JN`#$ZJ8_O^7H`(`"P`(`!$`?$"3]/W_E^,#$ZKB`Q2J
M]0,`JD%G,)%__O^7X6,!D>`#%:IL_O^7'P0`,4`!`%3@:T"Y``P4$A\00''!
M``!4X`,5JKK__Y?@`Q6J7O[_E\[__Q?@`Q6JV_W_E_O__Q?S4T&I]5M"J?=C
M0ZGY:T2I_7O.J,`#7];]>[6I_0,`D?-3`:FS``#P]`,`JF'F1_DB`$#YXE<`
M^0(`@-+AHP"1W?W_ET`"`#7A.T"Y`@"44B$,%!(_$$!Q)!!">L$``%3@`Q2J
M00"`4HO]_Y<?``!QX!>?&G/F1_GB5T#Y80)`^4$``<J!``"T7_[_EP``@%+Y
M__\7\U-!J?U[RZC``U_6_7NZJ?T#`)'U6P*IM@``\/4#`*K`YD?Y\U,!J?,#
M`:KW8P.I^6L$J0$`0/GA+P#Y`0"`TF`"0#D?]`!Q00``5',&`)'@`Q.J0_[_
ME^%3`9'W`P"JX`,5JA#__Y?T`P"JX`$`M#S^_Y?_`@#KJ`0`5`$`@-)@:F$X
M@&HA."$$`)&@__\UUN9'^>$O0/G``D#Y(```RD`)`+0S_O^7M```\(#B1_D:
M`$#Y``"`TD(C`-'X`P`J``0`D4%X8/BA__^UP0``D``+`!$BL$"Y`'Q]D\(%
M`#3A`P"JX`,:JC[]_Y>!XD?Y(```^>#\_[24XD?Y`0<`$8`"0/D?V"'X^%<`
MN>$#%:H@`$`Y'_0`<0080'HA!0!4M```\/A7@+DA`!7+X`H`D93B1_D8\WW3
M`,`ABYD"0/EH_?^7(&LX^$#Z_[3A5X"Y@`)`^0%X8?CB`P&JH!9`."$$`)$@
M\!\X8```-!_T`'%!__]4H`>`4D```#D``(#28FI@.")H(#@`!`"1HO__-<#_
M_Q<B`(!2(K``N5']_Y?Y`P"J8/?_M`)_?9/A`QJJ4/W_EX#B1_D9``#YS___
M%R$$`)'3__\7\U-!J?5;0JGW8T.I^6M$J?U[QJC``U_6_7N_J:```/#]`P"1
M`-Q'^0``0+G'_?^7_7O!J*(``/`C``#0`0``T$+T1_EC*"21(7PPD;?]_Q?]
M>[ZI_0,`D?,+`/FS``#P<]Y'^6`"0+FX_?^7Z___EV`"0+FU_?^7\PM`^00`
M`-#]>\*HA'@ZD>,#!*H%`(!2`@``L`$``-!"L!"1(>PPD>[\_Q<,"H32_V,L
MR_U[`*G]`P"1]5L"J;8``/#`YD?Y\U,!J?3C`)$!`$#YX2<0^0$`@-+Q_/^7
MXP,`*@0``-`"``#0A$`QD4)0,9'@`Q2J(0""TM7\_Y<?!``Q`0$`5`,`@-+`
MYD?YX2=0^0``0/D@``#*(`4`M*3]_Y<!?$"3/P1`\4D``%0`?2#4H/[_-P`(
M@M+S8R"+X0,3JN`#%*H"`(+2-?W_E_0#`*J@_?\W``0`$0!\0)/P_/^7XP,`
MJ@#]_[25?D"3'P`3ZX(``%0``!6+?P(`ZX/]_U1_`!/KB0``5&`"%8M_``#K
MX_S_5"``@E*?`@!KC/S_5.`#`ZKB`Q6JX0,3JG#]_Y?C`P"J'V@U.-3__Q?@
M`P.J#`J$TOU[0*GS4T&I]5M"J?]C+(O``U_6M/__%PP>@M+_8RS+_7L`J?T#
M`)'U6P*IM0``\/-3`:GT`P"J\P,!JJ#F1_GW8P.I^6L$J?LK`/D!`$#YX7<(
M^0$`@-(```#0`(`QD5[^_Y?X`P"JX06`4N`#%*KF_/^78`$`M````-#A`Q2J
M`*0QD0#__Y>UYD?YX7=(^:`"0/D@``#*8`D`M%/]_Y?@`Q2J3?W_EQ8``-#Y
M`P`JP=HQD>`#$ZH:``#0&P``T"[]_Y=:7S"1\P,`JGOC,9'WHP.1,_W_M&`"
M0#D?``!Q<Q*:FE@!`+3A`Q.JX`,8JG[\_Y?````UP=HQD0``@-(>_?^7\P,`
MJO/__Q?@`Q.J,OW_EP$$`%$C?$"38LIA.%^\`'$@`@!4(0<`$2````L?_#]Q
M+/K_5.4#%*KD`QNJXP,3JN`#%ZH"``#0`0""TD(D-9%-_/^7``0`$1\$0'&I
M``!4`'T@U.`#`2I_:B,XZ?__%^&C`9'@`Q>J]_S_E\#[_S7@>T"Y``P4$A\@
M0'%!^_]4X`,7JB$`@%(W_/^7P/K_->$#%ZH```#0`*0QD;7^_Y?@`Q>J@/S_
ME_0#`*JR__\7X`,4J@P>@M+]>T"I\U-!J?5;0JGW8T.I^6M$J?LK0/G_8RR+
MP`-?UN$#`*HB`$`Y0@``-<`#7]8A!`"17[P`<0`0@9KZ__\7P`<`M/U[OJG]
M`P"1\PL`^?,#`*H!`$`YP0``-0```-``7#"1\PM`^?U[PJA@_/\7Y_S_EP($
M`-%B`@*+?P("ZX(#`%1``$`Y'[P`<:`"`%1_`@+KX@(`5.`#`JH!]%\X/[P`
M<2$"`%1"!`#1?P("ZX(``%1``$`Y'[P`<6#__U1"`!/+0`@`D1\$0/$H`P!4
M0@0`D5\$0/')`0!4`'T@U$($`-'F__\7X@,`JNG__Q=_`@+KH?W_5&`"0#D?
MO`!QX/K_5````-``X#&1UO__%\,``)!C0`.1X0,3JN`#`ZI?_/^7\PM`^?U[
MPJC``U_6``"`TOS__Q<```#0`%PPD<O__Q?]>[FI_0,`D?-3`:FS``#P%```
MT&#F1_GU6P*I%0``T/<;`/D6``#0%P``T/<&,Y$!`$#YX3<`^0$`@-(@``#0
M`"@DD0`H`)$"#$"IX@\$J0(,0:GB#P6I`$!`>>##`'D```#0`.@QD:K]_Y<`
M``#0``PRD:?]_Y<```#0`"PRD:3]_Y<```#0`%`RD:']_Y>@;C*1G_W_EP``
M`-``K#*1G/W_E\"",9&:_?^7@-XRD9C]_Y?@`Q>JEOW_EP```-``+#.1D_W_
MEP```-``I#&1D/W_EP```-``5#.1>_W_EX```+3A`P"JX`,7JB+^_Y<```#0
M`)@SD73]_Y?A`P"J@```M````-``Q"^1&O[_EP```-``X#.1;/W_E^$#`*J@
M`0"TP((QD1/^_Y>@;C*1`0``T"&0-)$/_O^7<^9'^>$W0/E@`D#Y(```RB`"
M`+1B_/^7````T``@-)%;_?^7X0,`JF```+2`WC*1[___%P$``-#@1P&1(60T
MD4(!@-*Z^_^70/W_->%O`9'W__\7\U-!J?5;0JGW&T#Y_7O'J,`#7];]>[ZI
M_0,`D?,+`/G3``"08`I`N1\$`#%!`0!4````T`#<,I%`_?^70`$`M```0#D`
M`0`T'\``<>`'GQI@"@"Y8`I`N?,+0/G]>\*HP`-?U@``@%+Z__\7_7N_J?T#
M`)$Y_/^7Q/O_ET```+0``$#Y_7O!J,`#7];]>[VI_0,`D?5;`JD5``#0MIHT
MD?-3`:GS`P"JX`,6JB/]_Y>```"T`0!`.?0#`*KA```UX0,3JJ":-)'S4T&I
M]5M"J?U[PZC$_?\7X0,3JI?[_Y>``@"UX`,3JA3\_Y?U`P"JX`,4JA'\_Y>@
M`@"+``@`D6[[_Y?D`Q2J]0,`JN(#$ZH#``#0`0``T&/8,9$A)#61]OO_E^$#
M%:K@`Q:JY___%_-30:GU6T*I_7O#J,`#7]8,,I#2_V,LR_U[`*G]`P"1]5L"
MJ;8``/#U`P"J\U,!J>`C0)'4YD?Y]V,#J1<``-#Y:P2I^W,%J8$"0/D!Q`#Y
M`0"`TL```)``(`"1`HQ`J>(/!JD"#$*IX@\)J0(,0ZGB#PJI`@Q$J>(/"ZD"
M#$6IXH\'J0$,0/GA.P#Y`#!`^>!'`/G@@C&1W/S_EZ`"`+0!`$`Y\P,`JD$"
M`#2L__^7X"-`D0'$0/F``D#Y(```RD```+35^_^7X`,3J@PRD-+]>T"I\U-!
MJ?5;0JGW8T.I^6M$J?MS1:G_8RR+/_O_%Y/__Y?S`P"J``(`M?3C`9&``D#Y
M@```M1,``-!SVC21"@``%+W\_Y=@``"UE"(`D?C__Q<!`$`YH?__-"_[_Y?S
M`P"J0/__M.`#$ZJS^_^7`/A_TQ@``-``!`"1&/<TD0[[_Y?Z`P"J]`,`JF("
M0#EB"0`U]$,"D9,"0/F3`0"TX`,3JJ7\_Y?S`P"J0`D`M`$`0#D!"0`T*?W_
ME\`(`#3@`Q.J%?O_E_,#`*KX@P&1LP``M10#0/ET``"T@`)`.>`'`#7@`Q.J
ME/O_E_@#`*K@`QJJD?O_EQ@#``L8$Q`1&0``T!A_0)/@`QBJZ_K_E^4#&JHC
MXS&1X@,3J@0``+"$"#61]`,`J@$``+`A'#61<OO_E^`#%*H!.(!25_O_EQ\$
M`#'!!0!44/O_EP0`0+F?1`!Q0`4`5*```-`!``"PH@)`^>,#%*H`Q$?Y(4`U
MD0``0/DI^_^7$P"`TM;F1_G@(T"1`<1`^<`"0/D@``#*(//_M>`#$ZH,,I#2
M_7M`J?-30:GU6T*I]V-#J?EK1*G[<T6I_V,LB\`#7];@`Q2JX0,8JG,&`)&4
M"@"12_O_EZ___Q>4(@"1L/__%^`#%*K?_/^7@```-.`#%*K+^O^7\P,`JA@C
M`)&V__\7X0,#D>`#%*J]^O^7^@,`*D`!`#2@``#0XP,4JJ("0/D!``"P`,1'
M^2$L-I$``$#Y^_K_E]+__Q?@TT"Y``P4$A\00'&!_O]4\]M`N43[_Y=_`@!K
M`?[_5.#30+D`(``2'P`'<8']_U3@`QBJE/K_E_,#`*H```"P`,0TD3#\_Y=`
M"P"UN`)`^>`#&*HL^_^7^P,`JA\,`'%M`P!4`'Q`DP$``+``$`#1(7@WD0`#
M`(MG^O^7@`(`-7\3`'&@``!4>Q<`40#+>S@?O`!QP0$`5+4&0/F5`0"TX`,5
MJAC[_Y<?#`#Q"0$`5``0`-$!``"PH`(`BR&,-Y%5^O^7'P``<1@3E9K%_O^7
M(`T`->`#&*H!`(!2AOK_E_4#`"J`#``T0@"`4B$"@)+X(P:10/K_E^$#&*K@
M`Q4JP@"`TLCZ_Y?@(T8Y(`8`->`G1CD?#`%QP04`5.`K1CD?!`%Q804`5.`O
M1CD?#`%Q`04`5.`S1CD?(`%QH00`5.`W1CD?%`%Q000`5$(`@%(A!X"2X`,5
M*B?Z_Y?A`QBJX`,5*B(%@-*O^O^7!0``L.0#&*JE>#J1`0``L"/C,9'B`Q2J
M(:`WD>`#$ZK.^O^7X`,4JKCZ_Y?A`Q.JX((QD83\_Y?@`Q.JK/[_EV?__Q>X
M`D#Y3/K_E^$#`*K@`QBJ8?W_E_@#`*I`]/^UH/__%P(`@%(!`(#2X`,5*@;Z
M_Y=@!0"4^@,`J@(`D-+A`QBJX`,5*HSZ_Y?B`P"J'P``<2P#`%3@`Q4J^&,%
MD7[Z_Y?\`QBJX0,:JAH``+!:]S21%0"`TOL#!9'@`QNJP`4`E&)K=3C@`QBJ
MX0,:JK4&`)$8"P"1H/K_E[]2`/$A__]4!0``L.0#'*JE>#J1_P,&.<;__Q?A
M`QBJX`,:JE0%`)3>__\7`0``L````+`AD#21`-PRD1@``+`8%SB12?S_ESGC
M,9'<^?^7%0``L+5Z.I'D`P`JY0,5JN,#&:KB`Q2JX`,3J@$``+`AW#>1@OK_
ME^`#$ZH!.(!29_K_EQ\$`#$!]O]48/K_EP``0+D?1`!Q@?7_5,CY_Y=:!P`1
MY`,`*N8#%:KE`QHJXP,9JN(#%*KA`QBJX`,3JF_Z_Y?M__\7_7NZJ?T#`)'S
M4P&ILP``T/5;`JEUWD?Y]V,#J?EK!*G[<P6IH`)`N5_Z_Y?T`P"JH`)`N5SZ
M_Y>!XD(Y`>0".0```+``;#*1:_O_E\```+0!`$`Y/\0`<6$``%0`!$`Y0```
M-++]_Y=WWD?YM```\.`"0+E,^O^7`0``L&,!@%(A6#B1(@"`4N/Y_Y<@!`"U
M=MY'^<`"0+E#^O^78P"`4B(`@%(!``"P(6PXD=KY_Y?U`P"JX`D`M7?>1_G@
M`D"Y.?K_EV,`@%(B`(!2`0``L"'L.)'0^?^7]0,`JB`,`+0```"P`*0QD4/[
M_Y?V`P"J(`H`M.`"0+DK^O^7H0I`^>(#%JHA`$#YR_G_EU4``!0`"$#Y&X"`
M4IK"`I$U`(!2&P2@<A@40/FY!@!100=`N>`"0+D_`!5K#0$`5!KZ_Y<B?T"3
MX0,8J@,`@%)Z^?^7]@,`JB`!`+66P@*1P`9`N0`$`%$?`!EK0?G_5'?>1_DU
M`(!2&@``%`$`0/E`!T#Y'-AU^"`,0+D``!L*'P`0<>$``%0A"$#YX`,<JEKY
M_Y?`_?\UM08`$>#__Q?@`D"Y_?G_E\$"0/E#`(!2`@"`T@GZ_Y?A`P"J]/__
M%[4&`!'U^?^7X0,8JA_Y_Y?!!D"YX`)`N3\`%6LL__]4J?__%\`"0+GL^?^7
MH0I`^0(``+!"=#B1(0!`^8OY_Y>@"D#Y``!`^0`,0+D`];<VP`)`N>'Y_Y>A
M"D#Y(0!`^4KY_Y>B__\7,_S_E_8#`*K@`D"Y]@0`M-CY_Y>A"D#YX@,6JB$`
M0/EX^?^7X`,6JL+Y_Y=SWD?Y8`)`N<_Y_Y?U`P"J8`)`N<SY_Y<B`(!2`0``
ML"&(.)$`^?^7`@``L.$#`*I"W#B1X`,5JF?Y_Y=@`D"YD\("D<#Y_Y<?Y`(Y
M````L`"`,9'0^O^78`H`^<`!`+5@!D#YSOW_EV`*`/E``0"U````L`#T.)'[
M^/^7LOG_EX'"`I$B!$#YH0I`^4(`0/F%__\7E,("D0$X@%*`"D#YE?G_E^,#
M`"H?1`!Q(`$`5``$`!$?!`!QR0``5("*0*D!`$#Y````L`!X.9'F^/^7\U-!
MJ?5;0JGW8T.I^6M$J?MS1:G]>\:HP`-?UOU[OJG]`P"1\U,!J?,#`*JS_/^7
MJOS_E_0#`*I:_?^7P`$`-+,!`+1@`D`Y8`$`-`$``+#@`Q2J(0@UD1OY_Y>?
M`@#KH0``5.`#$ZKS4T&I_7O"J,OZ_Q?S4T&I_7O"J,`#7];_PPK1I0``T`;@
M`)$(X`&1_7L`J?T#`)&AY$?Y\PL`^2(`0/GB5P'Y`@"`TN*C`)'G`P*JP0!`
MN>=``)'$A$#X(0C`6N$`'_B!_&#3(QP(4R'<>-,A''"280`!JH/\:--C''B2
M9.!$JB$`!*KA@!_X'P$&ZP'^_U0#"(!21"!`^6,$`'%!-$#Y0B``D4:`7_@A
M``3*1`1`^80`!LHA``3*)/Q?TX$$`:HA?$"203P`^6'^_U0&)$"I*S./T@<@
M0:E+4*OR"A!`^<3\6],C_4+3A!0&JF-X":H!`0?*S?Q"TR$`"8JM>0:J(0`(
MRK!]0)(D0"2+X8M"J2$`"XM"``N+A``!BV%\0)(L``?*A``*"XP!!HIC``W*
MC`$'RF,`!(J,`0B+8P`!RHP!`HN"_%O30A0$JF,`!XN,`0(+XA]`^4(`"XMC
M``*+@OU;TT(4#*IC``(+@OQ"TT1X!*JB`03*CWQ`DD(`#(I"`!#*0@`!B^$C
M0/DA``N+0@`!BV'\6],A%`.J0@`!"X']0M,L>`RJA``,RHY]0)*!``.*Y"=`
M^2$`#\HA`!"+A``+BR$`!(M$_%O3A!0"JB$`!`MD_$+3@W@#JHP!`\IM?$"2
MY"M`^8P!`HJ,`0[*A``+BXP!#XN,`02+)/Q;TX04`:J,`00+1/Q"TX)X`JID
M``+*3WQ`DN,O0/F$``&*A``-RF,`"XN$``Z+A``#BX/]6]-C%`RJA``#"R/\
M0M-A>`&J0P`!RBY\0)+B,T#Y8P`,BF,`#\I"``N+8P`-BV,``HN"_%O30A0$
MJF,``@N"_4+33'@,JB$`#,J-?4"2(@`$BN$W0/E"``[*0@`/BR$`"XM"``&+
M8?Q;TR$4`ZI"``$+@?Q"TR1X!*J,`03*CWQ`DN$[0/F,`0.*C`$-RB$`"XN,
M`0Z+C`$!BT'\6],A%`*JC`$!"V'\0M,C>`.J@0`#RFY\0)+D/T#Y(0`"BB$`
M#\J$``N+(0`-BR$`!(N$_5O3A!0,JB$`!`M$_$+3@G@"JF0``LI-?$"2XT-`
M^80`#(J$``[*8P`+BX0`#XN$``.+(_Q;TV,4`:J$``,+@_U"TVQX#*I"``S*
MCWU`DD,``8KB1T#Y8P`-RF,`#HM"``N+8P`"BX+\6]-"%`2J8P`""R+\0M-!
M>`&JC`$!RBY\0)+B2T#YC`$$BHP!#\I"``N+C`$-BXP!`HMB_%O30A0#JHP!
M`@N"_$+31'@$JB(`!,J-?$"2X4]`^4(``XI"``[*(0`+BT(`#XM"``&+@?U;
MTR$4#*I"``$+8?Q"TR-X`ZJ!``/*;WQ`DN130/DA``R*(0`-RH0`"XLA``Z+
M(0`$BT3\6].$%`*J(0`$"X3]0M.$>`RJ;``$RHY\0)+C5T#YC`$"BHP!#\IC
M``N+C`$-BXP!`XLC_%O38Q0!JHP!`PM#_$+38G@"JH,``LI-?$"2Y%M`^6,`
M`8IC``[*A``+BV,`#XMC``2+)/Q"TX%X`:J/_5O30@`!RN\5#*I"``R*8P`/
M"T(`#<HD?$"20@`.BV_\0M/N7T#YS@$+BT(`#HMN_%O3SA4#JE%`+HO"`0(+
MCOU"T\QY#*I0_%O3(0`,RA`6`JHA``.*3OQ"TR$`!,KC>0.J(0`-B\YY`JKM
M8T#Y8@`.RJL!"XLM=)W2(0`+BXL!`\HS0#"+:P$12D(`$TIK`02+3$`LBP$"
M`0ODBTRI+=NM\C#\0M.$``V+0@`-BVL!!(LD_%O3A!0!JHP!`HL!>@&J<D$D
MBXL`"PO/`0'*8OU;TV3]0M-"%`NJBW@+JN\!$DJ102*+3``,"R(`"\KO02.+
M0@`12H3]0M-.0"Z+XXM-J6,`#8M"``V+[P$#BX/]6]-C%`RJC'@,JG`!#,K.
M`0*+\D$CBV,`#PL0`A)*8OQ;TV_\0M-"%`.J$$(AB^-Y`ZKAOTZIT4$BBT(`
M#@N$`0/*A``12D[\0M.$0"N+(0`-B^\!#8L0`@&+0?Q;TR$4`JK">0*J:P`"
MRH0`#XL20B&+(0`0"VL!$DHQ_%O3,/Q"TS$6`:H!>@&J:T$LBTP``<J/0#&+
M)`($"XP!#TJ#02.+D?Q;T^ZS3ZDQ%@2JC_Q"T^1Y!*K.`0V+C`$-BVL!#HLN
M``3*<D$QBRL""PO.`1)*8P`,B\)!(HML_5O3[H=`^8P5"ZK.`0V+<$`LBT(`
M#HMN_4+3RWD+JHP!`PN#``O*8P`02I']6]-A0"&+,18,JN.+0/E20#&+(@("
M"V,`#8LA``.+@_U"TVQX#*I0_%O3;P$,RA`6`JKO`1)*[T$DBT3\0M.">`*J
M,T`PB^.34:D!`@$+C@$"RC#\6]/.`1-*$!8!JLY!*XLK_$+38P`-BV%Y`:KO
M`0.+0P`!RO)!,(L/`@\+8P`22H0`#8ML0"R+\/U;T^.70/D0%@^JS@$$BV,`
M#8O103"+C`$#B^/]0M-O>`^J#@(."R0`#\J$`!%*T/U;TX1`(HL0%@ZJXIM`
M^9)!,(L,`@P+0@`-BX0``HO"_4+33G@.JI#]6]/K`0[*$!8,JFL!$DIK02&+
MD4`PB^&?0/D$`@0+(0`-BY#\6]-K`0&+@?U"TR%X#*H0%@2JPP$!RF,`$4IR
M03"+8T`OBX_\0M/D>02J"P(+"R(`!,I"`!)*</U;TT)`+HL0%@NJ[#M4J8P!
M#8O.`0V+8P`,BT(`#HMQ0#"+`P(#"VS]0M-P_%O3;OQ"TQ`6`ZJ+>0NJPWD#
MJHP`"\I20#"+;P$#RHP!$4KO`1)*@4$AB^]!)(OL$U6I`@(""U#\6],0%@*J
MC`$-BX0`#8LA``R+[P$$BS%`,(L!`@$+)/Q;TX04`:KO`00+1/Q"TX)X`JIL
M``+*Y+-`^8P!$4J,02N+*_Q"TV%Y`:J-``V+C0$-BTP``:HN``(*C`$/BHX!
M#JKD_5O3SD$CBX04#ZKCMT#YK0$$"XR;E])LX['R8P`,B\X!`XNC_5O38Q0-
MJLX!`POC_4+3;W@/JC``#ZKD`0$*$`(-B@0"!*J$0"*+XKM`^4(`#(N$``*+
MPOU;TT(4#JJ$``(+HOU"TTUX#:KP`0VJJP$/"A`"#HH+`@NJ:T$AB^&_0/DA
M``R+:P$!BX'\6],A%`2J:P$!"\']0M,N>`ZJL`$.JL,!#0KAPT#Y$`($B@,"
M`ZHA``R+8T`OBV,``8MA_5O3(10+JF,``0N!_$+3)'@$JL\!!*J"``X*X<=`
M^>\!"XKB`0*J(0`,BT)`+8M"``&+8?Q;TR$4`ZI"``$+8?U"TRMX"ZJ-``NJ
M80$$"JT!`XJA`0&J[<M`^2%`+HNM`0R+(0`-BTW\6].M%0*J(0`-"VW\0M.C
M>0.J;0$#JFX`"PJM`0**K0$.JJ1!)(OMST#YK0$,BX0`#8LM_%O3K14!JH0`
M#0M-_$+3HGD"JFT``JI.``,*K0$!BJT!#JJK02N+[=-`^:T!#(MK`0V+C?Q;
MTZT5!*IK`0T++?Q"TZ%Y`:I-``&J+@`""JT!!(JM`0ZJHT$CB^W70/FM`0R+
M8P`-BVW]6].M%0NJ8P`-"XW\0M.D>02J+0`$JHX``0JM`0N*K0$.JJ)!(HOM
MVT#YK0$,BT(`#8MM_%O3K14#JD(`#0MM_4+3JWD+JHT`"ZIN`00*K0$#BJT!
M#JJA02&+[=]`^:T!#(LA``V+3?Q;TZT5`JHA``T+;?Q"TZ-Y`ZIM`0.J;@`+
M"JT!`HJM`0ZJI$$DB^WC0/FM`0R+A``-BRW\6].M%0&JA``-"TW\0M.B>0*J
M;0`"JDX``PJM`0&*K0$.JJM!*XOMYT#YK0$,BVL!#8N-_%O3K14$JFL!#0LM
M_$+3H7D!JDT``:HN``(*K0$$BJT!#JJC02.+[>M`^:T!#(MC``V+;?U;TZT5
M"ZIC``T+C?Q"TZ1Y!*HM``2JC@`!"JT!"XJM`0ZJHD$BB^WO0/FM`0R+0@`-
MBVW\6].M%0.J0@`-"VW]0M.K>0NJC0`+JFX!!`JM`0.*K0$.JJ%!(8OM\T#Y
MK0$,BR$`#8M-_%O3K14"JB$`#0MM_$+3HWD#JFT!`ZIN``L*K0$"BJT!#JJD
M022+[?=`^:T!#(N$``V++?Q;TZT5`:J$``T+3?Q"TZ)Y`JIM``*J3@`#"JT!
M`8J1_%O3K0$.JC$6!*JK02N+[?M`^:T!#(MK`0V++?Q"TZ%Y`:IK`1$+30`!
MJBX``@JM`02*</U;TZT!#JH0%@NJHT$CBW']0M/M_T#YK0$,BV,`#8MN0#"+
M$`(#"X/\0M-D>`2J#_Y;TRT`!*J#``$*K0$+BN\5$*JM`0.J*WH+JN,#0?FB
M02*+I>1'^6P`#(M"``R+S#J8TDU`+XOO`0(+@@`+RDQ,N?)"``Y*[OU;TT%`
M(8O.%0^JX@=!^0/^0M-P>!"J0@`,BR$``HOB_4+3,T`NB\X!`0MA`1#*3W@/
MJB$`#4H1`@_*)$`DB\W]6]/A"T'Y,0(32JT5#JHQ0BN+(0`,B^L/0?F$``&+
MDD`MBZT!!`MK`0R+P?U"TS$""XNK_5O3+G@.JFL5#:KD$T'YXP$.RC-"*XMC
M`!)*:P$1"X0`#(MP0#"+$`($BW+]6].D_4+34A8+JHUX#:IQ_4+3XQ=!^<(!
M#<HK>@NJ'D(RBT(`$TI0`A`+8P`,BZ$!"\I/0"^+(0`>2N\!`XL#_EO38Q00
MJBY`+HOA&T'YXD$CBP3^0M-C``\+D'@0JB$`#(O.`0&+9`$0RF'\6].$``)*
M(10#JHU`+8OB'T'YT4$ABR$`#@MO_$+30@`,B^-Y`ZJM`0*+(OQ;TT(4`:H/
M`@/*[P$12B[\0M.R02*+ZT$KBT(`#0O!>0&J[R-!^5'\6],Q%@*J9``!RN\!
M#(M-_$+3:P$/BZ)Y`JIO03&+*P(+"^XG0?F$`!)*+0`"RH1`,(MP_5O3S@$,
MBQ`6"ZJM`0]*;_U"TX0`#HOK>0NJDD`PBTX`"\H$`@0+S@$22J-!(XO!02&+
MD/Q;T^XO0?D0%@2J[2M!^<X!#(LA``Z+COQ"TZT!#(O$>02J8P`-BVT!!,I^
M0#"+`P(#"ZT!'DJB02*+</Q;T^TS0?D0%@.JK0$,BS)`,(M"``V+;?Q"TZ-Y
M`ZH!`@$+CP`#RN\!$DHP_%O3[T$KBQ`6`:KK-T'Y44`PBP("`@MK`0R+[P$+
MBRO\0M-A>0&J4/Q;TVX``<H0%@*JS@$12LY!)(OR03"+Y#M!^0\"#PN$``R+
M\/U;T\X!!(M$_$+3@G@"JA`6#ZHM``+*K0$22M%!,(NM02.+#@(."^,_0?G0
M_5O3$!8.JF,`#(NM`0.+X_U"TV]X#ZJR03"+2P`/R@T"#0MK`1%*:T$AB[#]
M6]/A0T'Y$!8-JB$`#(MK`0&+P?U"TRYX#JIQ03"+Y`$.R@L""PN$`!)*L/U"
MTX1`(HL->@VJXD=!^<,!#<IC`!%*</U"TT(`#(MC0"^+A``"BV+]6]-"%`NJ
M"WH+JJ$!"\K&0"V+DD`BBT(`!`OD2T'Y3_Q;T^\5`JHA`!)*A``,BR%`+HMC
M``2+1/Q"TW%`+XOC`0,+[T]!^8)X`JIN`0+*:@$*"^\!#(O.`1%*(0`/BV_\
M6]/O%0.J0@`("R$`#PL"J`&I)/Q;TX04`:HA``D+A``.B^Y30?G,`0R+A@$&
MBX8`!@L&!`"I8?Q"TR%X`ZHG``<+!P@`^>%70?F@`$#Y(```RD```+1R]?^7
M_7M`J?,+0/G_PPJ1P`-?UOU[OZD`$(#2_0,`D<;T_Y<?_`*I(F"$TJ+HK/("
M``#Y(G&5TA]X`+FB^;WR`@0`^<*?F])"%[/R`@@`^<*.BM)"!J+R`@P`^0(^
MG-)">KCR`A``^?U[P:C``U_6_7N\J?T#`)'S4P&I\P,`JD!\0)/U6P*I]`,`
MJF(60/GW&P#Y0PP`"U\``^N)``!48AI`^4($`)%B&@#Y8AI`^77B`)%`=$"+
M8X("J6!Z0+F``P`T%@B`4M8"`$N?`A9KH,(@BY;2EAK"?D"3'P`!ZZ(``%0#
M``*+/P`#ZT(``%0`?2#4-P`"BQ\``>MI``!4'P`7ZV/__U0@]?^78'I`N<`"
M``M@>@"Y'P`!<<$"`%3@`Q.JE/O_EY0"%DOA`Q>J=^(!D9_^`'&,`@!4@GY`
MDS\`%>N)``!4H`("BS\``.L#_?]4/P`5ZX(``%0@``*+OP(`ZV/\_U3@`Q6J
M!_7_EW1Z`+GS4T&I]5M"J?<;0/G]>\2HP`-?UC\`%>MI``!4/P`7Z^/Z_U0V
M``&1OP(!ZVD``%2_`A;K0_K_5"(,0*FB#@"IE`(!42(,0:FB#@&I(@Q"J:(.
M`JD@!$.IH`8#J>`#$ZIH^_^7X0,6JM;__Q?]>[RI_0,`D?-3`:GT`P"J\P,!
MJO5;`JDUX`"1]QL`^2`40/DV*$"Y-S!`N>$/@!(`(`-3U@K`6@($`!'W"L!:
MH<H@.*#"(HM?X`!QC0D`5`$(@%(B``)+`0"`4D)\0),R]/^7X`,3JDO[_Y=_
M_@.I?_X$J7_^!:E_-@#Y=UH.*>`#$ZI$^_^78`)`^0#\6-.``@`Y8`)`^0#\
M4-.`!@`Y8`)`^0#\2-.`"@`Y8`)`^8`.`#E@!D#Y`/Q8TX`2`#E@!D#Y`/Q0
MTX`6`#E@!D#Y`/Q(TX`:`#E@!D#Y@!X`.6`*0/D`_%C3@"(`.6`*0/D`_%#3
M@"8`.6`*0/D`_$C3@"H`.6`*0/F`+@`Y8`Y`^0#\6-.`,@`Y8`Y`^0#\4-.`
M-@`Y8`Y`^0#\2-.`.@`Y8`Y`^8`^`#E@$D#Y`/Q8TX!"`#E@$D#Y]5M"J0#\
M4-.`1@`Y8!)`^0#\2-.`2@`Y8!)`^8!.`#G@`Q.J\U-!J?<;0/G]>\2H=/3_
M%P$'@%(B``)+`0"`4D)\0)/G\_^7N___%_U[OZG]`P"1_7O!J,`#7]8O=&UP
M`%!!4E]435!$25(`5$5-4$1)4@!435``55-%4@!54T523D%-10`N+@`E<R\E
M<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z
M.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z
M`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!
M0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)
M0E)!4EE?4$%42`!365-414T`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P
M87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S`$%21U8`&`!P97)L`%!!4CHZ4&%C:V5R.CI615)324].`#$N
M,#4P`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M
M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M
M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G
M"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP
M.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y0
M05(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E
M;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M
M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I
M8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S
M:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92![
M"B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D
M;6%G:6-?<&]S(#X](#`I('L*<V5E:RA?1D@L("1M86=I8U]P;W,L(#`I.PIR
M96%D*%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)
M0RDI.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^
M/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M
M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E
M860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E
M;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M
M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@
M)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1I;F9O(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O
M+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L
M("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O
M<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H
M*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+
M7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@
M("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H
M)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D
M14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@
M82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!
M4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE
M;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H
M0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E
M("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$
M:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N
M<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F
M:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@
M/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM
M>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@
M)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H
M(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H
M1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO
M)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H
M<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H
M+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N
M="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`
M(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHD>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O
M<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T
M("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#([
M"G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS
M92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@)&9H+"`B
M/"(L("1P<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@?'P@)&UT:6UE
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I9V5S="([
M"GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@
M)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z
M("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E
M("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@
M:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`%]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@``````$;`SOT````'0```!B5__]$
M!0``*)?__PP!``!8E___(`$``)B7__\T`0``^)?__U@!```LF/__>`$``.B8
M__^L`0``,)G__]`!``#`F?___`$```R;__\X`@``E)O__V`"``!HG?__G`(`
M`*"=__^\`@``])W__^`"```DG___%`,``"B?__\H`P``_*#__W0#```<H?__
MB`,``""B___$`P``Q*/___0#```<I/__&`0``#RD__\X!```\*3__W`$``#T
MJO__U`0``$"N__\4!0``I*[__W`%``!$O___F`4``*"___^X!0``$,'__^P%
M````````$``````````!>E(`!'@>`1L,'P`0````&````!26__\P````````
M`!`````L````,);__SP`````````(````$````!<EO__8`````!!#B"=!)X#
M0I,"5-[=TPX`````'````&0```"8EO__-`````!$#A"=`IX!1][=#@`````P
M````A````*R6__^\`````$$.0)T(G@=$DP:4!94$E@.7`I@!8PK>W=?8U=;3
MU`X`00L`(````+@````TE___2`````!!#C"=!IX%0I,$3M[=TPX`````*```
M`-P```!8E___D`````!!#D"=")X'0Y,&E`5$E026`UO>W=76T]0.```X````
M"`$``+R7__],`0```$$.X`&=')X;0I48EA=%DQJ4&9<6F!69%)H3`DK>W=G:
MU]C5UM/4#@`````D````1`$``,R8__^(`````$$.L`&=%IX50I,4E!->WMW3
MU`X`````.````&P!```LF?__U`$```!!#F"=#)X+0I4(E@=$DPJ4"4.7!I@%
MF02:`P)JWMW9VM?8U=;3U`X`````'````*@!``#$FO__.`````!!#A"=`IX!
M1M[=#@`````@````R`$``-R:__]4`````$$.()T$G@-"DP)*WMW3#@`````P
M````[`$```R;__\P`0```$(.T$!!G8H(GHD(0I6&"):%"$.3B`B4AP@"0]W>
MU=;3U`X`$````"`"```(G/__!`````````!(````-`(``/B;___4`0```$(.
M\"%!G9X$GIT$0I6:!):9!$*3G`24FP1&EY@$F)<$F98$FI4$FY0$`F?=WMO9
MVM?8U=;3U`X`````$````(`"``"`G?__(``````````X````E`(``(R=__\$
M`0```$(.()T$G@-"DP)'WMW3#@!!#B"3`IT$G@-O"M[=TPX`00M"#@#3W=X`
M```L````T`(``%2>__^D`0```$$.<)T.G@U"DPR4"T25"I8)0I<(`E_>W=?5
MUM/4#@`@``````,``,B?__]8`````$$.()T$G@-"DP)0"M[=TPX`00L<````
M)`,``/R?__\@`````$$.$)T"G@%&WMT.`````#0```!$`P``_)___[0`````
M00XPG0:>!4*5`I8!0Y,$E`-,"M[=U=;3U`X`00M9WMW5UM/4#@``8````'P#
M``!XH/__!`8```!"#I"#`D&=LB">L2!"E:X@EJT@1).P()2O($*7K""8JR!#
MF:H@FJD@FZ@@G*<@:0K=WMO<V=K7V-76T]0.`$$+`F8*W=[;W-G:U]C5UM/4
M#@!!"SP```#@`P``&*;__TP#````00Y@G0R>"T*3"I0)0I4(E@=$EP:8!9D$
MF@.;`IP!`LG>W=O<V=K7V-76T]0.```L````(`0``"2I__]D`````$$.()T$
MG@-"DP*4`5(*WMW3U`X`00M"WMW3U`X````H````4`0``,R/___$`0```$$.
M4)T*G@E"DPB4!T.5!@)F"M[=U=/4#@!!"R0```!\!```+*G__Z`0````00ZP
M!42=5IY50Y-4`Q\$W=[3#@`````<````I`0``*2Y__]<`````$$.$)T"G@%5
MWMT.`````#````#$!```X+G__W`!````00Y`G0B>!T*3!I0%1I4$E@.7`GP*
MWMW7U=;3U`X`00L````P````^`0``!R[__^4`0```$$.0)T(G@="DP:4!4.5
M!)8#0I<"`E8*WMW7U=;3U`X`00L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#`A````````T"`````````!
M`````````"@#`````````0`````````S`P````````\`````````@00`````
M```,`````````#@:````````#0````````#<2P```````!D`````````@)L!
M```````;``````````@`````````&@````````"(FP$``````!P`````````
M"`````````#U_O]O`````"`"````````!0`````````0#0````````8`````
M````"`,````````*`````````)\$````````"P`````````8`````````!4`
M```````````````````#`````````'"=`0```````@````````#0!0``````
M`!0`````````!P`````````7`````````&@4````````!P````````"P$0``
M``````@`````````N`(````````)`````````!@`````````&```````````
M`````````/O__V\``````0``"`````#Y__]O`````!``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````4!H```````!0&@```````%`:````````4!H```````!0&@``
M`````%`:````````4!H```````!0&@```````%`:````````4!H```````!0
M&@```````%`:````````4!H```````!0&@```````%`:````````4!H`````
M``!0&@```````%`:````````4!H```````!0&@```````%`:````````4!H`
M``````!0&@```````%`:````````4!H```````!0&@```````%`:````````
M4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:````
M````4!H```````!0&@```````%`:````````4!H```````!0&@```````%`:
M````````4!H```````!0&@```````%`:````````4!H```````!0&@``````
M`%`:````````D)L!``````!0'@````````````````````````````#<2P``
M```````````````````````````X&@``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@`0``````_____P````#L2P```````!=,````````````
M``````#Q2P```````/%,````````_$L````````#30````````1,````````
M```````````(3`````````U,``````````````````"E3@```````$=#0SH@
M*$%L<&EN92`Q,"XR+C`I(#$P+C(N,```+G-H<W1R=&%B`"YI;G1E<G``+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT````````````````````````````````````````
M````````````````````````````````````````````````````````"P``
M``$````"```````````"``````````(````````:````````````````````
M`0```````````````````!,```#V__]O`@`````````@`@```````"`"````
M````Z``````````#``````````@````````````````````=````"P````(`
M````````"`,````````(`P````````@*````````!`````,````(````````
M`!@`````````)0````,````"`````````!`-````````$`T```````"?!```
M`````````````````0```````````````````"T````$`````@````````"P
M$0```````+`1````````N`(````````#``````````@`````````&```````
M```W````!````$(`````````:!0```````!H%````````-`%`````````P``
M`!$````(`````````!@`````````00````$````&`````````#@:````````
M.!H````````0````````````````````!````````````````````#P````!
M````!@````````!0&@```````%`:``````````0``````````````````!``
M``````````````````!'`````0````8`````````4!X```````!0'@``````
M`(PM```````````````````0````````````````````30````$````&````
M`````-Q+````````W$L````````0````````````````````!```````````
M`````````%,````!`````@````````#L2P```````.Q+````````2CT`````
M``````````````$```````````````````!;`````0````(`````````.(D`
M```````XB0```````/0````````````````````$````````````````````
M:0````$````"`````````#"*````````,(H````````L!0``````````````
M````"````````````````````',````.`````P````````"`FP$``````(";
M````````"`````````````````````@`````````"`````````!_````#P``
M``,`````````B)L!``````"(FP````````@````````````````````(````
M``````@`````````BP````8````#`````````)";`0``````D)L```````#@
M`0````````0`````````"``````````0`````````)0````!`````P``````
M``!PG0$``````'"=````````D`(```````````````````@`````````"```
M``````"9`````0````,``````````*`!````````H````````'@`````````
M```````````(````````````````````GP````@````#`````````'B@`0``
M````>*````````!8$```````````````````"````````````````````*0`
M```!````,````````````````````'B@````````'```````````````````
M``$``````````0`````````!`````P````````````````````````"4H```
D`````*T````````````````````!````````````````````
